<?php

/**
 * Fluxus functions and definitions.
 *
 * @package fluxus
 * @since fluxus 1.0
 */


/**
 * Define common constants.
 */
define( 'FLUXUS_URI',         get_template_directory_uri() );
define( 'FLUXUS_CSS_URI',     FLUXUS_URI . '/css' );
define( 'FLUXUS_JS_URI',      FLUXUS_URI . '/js' );
define( 'FLUXUS_IMAGES_URI',  FLUXUS_URI . '/images' );

define( 'FLUXUS_DIR',         get_template_directory() );
define( 'FLUXUS_LIB_DIR',     FLUXUS_DIR . '/lib' );
define( 'FLUXUS_INC_DIR',     FLUXUS_DIR . '/inc' );
define( 'FLUXUS_CSS_DIR',     FLUXUS_DIR . '/css' );
define( 'FLUXUS_JS_DIR',      FLUXUS_DIR . '/js' );
define( 'FLUXUS_WIDGETS_DIR', FLUXUS_INC_DIR . '/widgets' );
define( 'WP_PRE_4',           (int) get_bloginfo('version') < 4 );

/**
 * Require various files.
 */
require_once FLUXUS_LIB_DIR . '/intheme-utils.php';                       // File contains a bunch of useful utilities.
require_once FLUXUS_LIB_DIR . '/class-transient-caching.php';             // Class implementing caching using WP Transients API.
require_once FLUXUS_LIB_DIR . '/intheme-menu-walker.php';                 // Custom menu walker.
require_once FLUXUS_LIB_DIR . '/appreciate.php';                          // Appreciate Post functionality.
require_once FLUXUS_INC_DIR . '/helpers.php';                             // Theme specific helpers.
require_once FLUXUS_INC_DIR . '/fluxus-theme.php';
require_once FLUXUS_INC_DIR . '/slider.php';                              // Full page slider functionality.
require_once FLUXUS_INC_DIR . '/portfolio/portfolio.php';                 // Portfolio functionality.
require_once FLUXUS_INC_DIR . '/contacts.php';                            // Contacts page functionality.
require_once FLUXUS_INC_DIR . '/background.php';                          // Page with background image functionality.
require_once FLUXUS_INC_DIR . '/template-tags.php';                       // Custom template tags for this theme.
require_once FLUXUS_INC_DIR . '/tweaks.php';                              // Various functionality tweaks.
require_once FLUXUS_INC_DIR . '/shortcodes.php';                          // Shortcodes.
require_once FLUXUS_INC_DIR . '/post-formats.php';                        // Post formats.
require_once FLUXUS_INC_DIR . '/widgets.php';                             // Widgets.
require_once FLUXUS_INC_DIR . '/plugin-support.php';                      // 3rd party plugin support.
require_once FLUXUS_INC_DIR . '/customize/class-fluxus-customize.php';    // Customize.
require_once FLUXUS_INC_DIR . '/upgrade.php';                             // All things regarding theme version update.

if ( is_admin() ) {
  require_once FLUXUS_LIB_DIR . '/class-tgm-plugin-activation.php';
}

/**
 * Initialize.
 */
function fluxus_init() {

  Fluxus_Customize::init();

  /**
   * Note, if you are changing the existing size dimensions,
   * then Wordpress will not automatically regenerate all the images.
   *
   * To do so, you could try using it_regenerate_wp_images() function.
   * Put it inside your admin_init hook, and visit admin section.
   * After waiting for usually a long time, all the images will be
   * available in a newly specified size.
   *
   * Custom image sizes:
   */

  add_image_size( 'fluxus-other-projects', 220, 220, false );          // Used on: Other Projects
  add_image_size( 'fluxus-thumbnail', 583, 328, true );                // Used on: Horizontal Blog
  add_image_size( 'fluxus-thumbnail-2x', 1166, 656, true );
  add_image_size( 'fluxus-thumbnail-uncropped', 583, 328, false );     // Used on: Vertical Blog
  add_image_size( 'fluxus-thumbnail-uncropped-2x', 1166, 656, false );
  add_image_size( 'fluxus-gallery-thumbnail', 500, 500, true );        // Used on: Content Gallery
  add_image_size( 'fluxus-max', 1920, 1280, false );                   // Maximum image size displayed on site.

  add_filter( 'show_admin_bar' , '__return_false' );                  // Remove admin bar for everyone

}
add_action( 'init', 'fluxus_init', 1 );


/**
 * Initialize Admin.
 */
function fluxus_admin_init() {

  /**
   * General scripts and styles for admin area.
   */
  fluxus_enqueue_script( 'fluxus-wp-admin', 'wp-admin/admin.js' );
  fluxus_enqueue_style( 'fluxus-wp-admin', 'wp-admin/admin.css' );

  add_editor_style( 'css/wp-admin/editor-styles.css' );

  global $wp_file_descriptions;
  $wp_file_descriptions['user.php'] = __( 'Use to add custom PHP code', 'fluxus' );
  $wp_file_descriptions['user.css'] = __( 'Use to add custom CSS code', 'fluxus' );

}
add_action( 'admin_init', 'fluxus_admin_init', 1 );



/**
 * Setup plugins.
 */
function fluxus_required_plugins() {

    $plugins = array(
      array(
        'name'      => 'Contact Form 7',
        'slug'      => 'contact-form-7',
        'required'  => false
      )
    );

    $config = array(
      'domain'            => 'fluxus',
      'parent_menu_slug'  => 'plugins.php',
      'parent_url_slug'   => 'plugins.php',
      'menu'              => 'install-required-plugins',
      'has_notices'       => true,
      'is_automatic'      => false,            // Automatically activate plugins after installation or not
      'message'           => '',               // Message to output right before the plugins table
      'strings'           => array(
        'menu_title' => __( 'Install Fluxus Compatible Plugins', 'fluxus' )
      )
    );

    tgmpa( $plugins, $config );

}
add_action( 'tgmpa_register', 'fluxus_required_plugins' );



/**
 * Specify the maximum content width.
 * This is based on CSS, when screen becomes big enough the content
 * area becomes fixed, so there is no need to have bigger images.
 */
if ( ! isset( $content_width ) ) {
  $content_width = 1021;
}


/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since fluxus 1.0
 */
function fluxus_setup() {

  /**
   * Make theme available for translation
   * Translations can be filed in the /languages/ directory
   */
  load_theme_textdomain( 'fluxus', FLUXUS_DIR . '/languages' );

  /**
   * Enable theme support for standard features.
   */
  add_theme_support( 'post-thumbnails' );
  add_theme_support( 'automatic-feed-links' );

  /**
   * Register menus.
   */
  register_nav_menus( array(
    'header_primary'  => __( 'Header Primary Menu', 'fluxus' ),
    'header_secondary'  => __( 'Header Secondary Menu', 'fluxus' ),
    'footer_primary'  => __( 'Footer Primary Menu', 'fluxus' )
  ) );


  /**
   * Enable shortcodes for widgets.
   */
  add_filter( 'widget_text', 'do_shortcode' );


  /**
   * Initialize theme options.
   */
  require_once FLUXUS_INC_DIR . '/options.php';
  if ( !function_exists( 'optionsframework_init' ) ) {
    define( 'OPTIONS_FRAMEWORK_DIRECTORY', FLUXUS_URI . '/options-framework/' );
    require_once dirname(__FILE__) . '/options-framework/options-framework.php';
  } else {
    add_action( 'admin_init', 'deactivate_options_framework_plugin' );
  }

}
add_action( 'after_setup_theme', 'fluxus_setup' );


/**
 * Enqueue scripts and styles.
 */
function fluxus_scripts_and_styles() {

  /**
   * CSS
   */
  fluxus_enqueue_style( 'fluxus-global', 'global.css' );         // Global CSS, should consist of tags only
  fluxus_enqueue_style( 'fluxus-grid', 'grid.css' );             // Fluid grid used in content columns
  fluxus_enqueue_style( 'fontello-icons', 'fontello.css' );      // Fontello font icon, use fonts/config.json to add more
  wp_enqueue_style( 'style', get_stylesheet_uri(), array(), FluxusUpgrade::VERSION );
  fluxus_enqueue_style( 'fluxus-responsive', 'responsive.css' ); // Responsive rules

  if ( get_theme_mod( 'skin' ) ) {
    fluxus_enqueue_style( 'fluxus-skin', 'skins/' . get_theme_mod( 'skin' ) ); // Skin
  }
  Fluxus_Customize::enqueue_style();

  // Custom CSS rules.
  wp_enqueue_style( 'fluxus-user', FLUXUS_URI . '/user.css', array(), FluxusUpgrade::VERSION );

  /**
   * Load JavaScript files.
   *
   * We don't specify dependencies and simply rely on the script order.
   * fluxus_enqueue_script helper is used to apply common params like $version, $in_footer and path.
   */
  wp_enqueue_script( 'underscore' );
  wp_enqueue_script( 'jquery' );

  fluxus_enqueue_script( 'tinyscrollbar',   'jquery.tinyscrollbar.js' );  // Scrollbar plugin
  fluxus_enqueue_script( 'sharrre',         'jquery.sharrre.js' );        // Share count plugin
  fluxus_enqueue_script( 'jquery-transit',  'jquery.transit.js' );        // CSS3 transition plugin
  fluxus_enqueue_script( 'fluxus-helpers',  'helpers.js' );               // Helpers used by Fluxus
  fluxus_enqueue_script( 'fluxus-utils',    'utils.js' );                 // Other tiny plugins
  fluxus_enqueue_script( 'fluxus-grid',     'jquery.fluxus-grid.js' );    // Grid portfolio layout plugin
  fluxus_enqueue_script( 'fluxus-reveal',   'jquery.reveal.js' );         // Modal box plugin
  fluxus_enqueue_script( 'fluxus-lightbox', 'jquery.fluxus-lightbox.js'); // Modal box plugin
  fluxus_enqueue_script( 'iscroll',         'iscroll.js' );               // Used to create mobile friendly scrolling containers
  fluxus_enqueue_script( 'fluxus-slider',   'jquery.fluxus-slider.js' );  // Full Page Slider plugin
  fluxus_enqueue_script( 'burger-menu',     'burger-menu.js' );           // Navigation menu for mobile devices
  fluxus_enqueue_script( 'fastclick',       'fastclick.js' );             // Removes 300ms delay on click events on touch devices
  fluxus_enqueue_script( 'fluxus',          'main.js', array( 'jquery', 'underscore' ) ); // Obviously this is the main script
  fluxus_enqueue_script( 'fluxus-user',     'user.js', array( 'fluxus' ) );  // This file should hold user JS modifications

  if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
    wp_enqueue_script( 'comment-reply' ); // WP standard comment reply script
  }

}
add_action( 'wp_enqueue_scripts', 'fluxus_scripts_and_styles' );

include_once FLUXUS_INC_DIR . '/user.php'; // User modifications.
