(function ($) {

$(function () {

    var $portfolio = $('.portfolio-grid'),
        grid       = $portfolio.data('grid'),
        maxSize    = $portfolio.data($portfolio.data('orientation') == 'horizontal' ? 'rows' : 'columns');

    function updateInfo() {
        $('.grid-project').each(function () {
            var $el = $(this),
                size = $el.data('size') || 1,
                cropping = $el.data('cropping') || 'center center';

            $el.find('.meta-info').html(
                'Size: x%d &nbsp;&nbsp; cropping: %s'.replace('%d', size).replace('%s', cropping)
            );
        });
    }

    $('.grid-project .inner').each(function () {
        var $el = $(this),
            $project = $el.closest('.grid-project'),
            $info = $('<span class="meta-info"></span>');

        $el.append('<a href="#" class="btn btn-change-size dashicons-before dashicons-editor-distractionfree">' + wpVars['clickToChangeSize'] + '</a>')
        $el.append('<a href="#" class="btn btn-change-cropping dashicons-before dashicons-image-crop">Change cropping mode</a>')

        $project.find('.hover-box').append($info);
        updateInfo();
    });

    $('.preview').click(function (e) {
        e.preventDefault()
    });


    // Clicking on project should change it's size, if the maximum size is reached, the size should go back to the smallest.
    $('.grid-project .btn-change-size').click(function (e) {
        e && e.preventDefault();

        var $el = $(this),
            $project = $el.closest('.grid-project'),
            size = $project.data('size');

        size = size < maxSize ? size + 1 : 1;

        $project.data('size', size);

        grid.render({
            force: true
        });
        updateInfo();
    });

    $('.grid-project .btn-change-cropping').click(function (e) {
        e && e.preventDefault();

        var $el = $(this),
            $project = $el.closest('.grid-project'),
            croppingPoint = $project.data('cropping') || 'center center',
            croppingOptions = [
                'top center',
                'top right',
                'center right',
                'bottom right',
                'bottom center',
                'bottom left',
                'center left',
                'top left'
            ],
            index = croppingOptions.indexOf(croppingPoint);

        index++;
        if (index == croppingOptions.length) {
            index = 0;
        }

        $project.data('cropping', croppingOptions[index]);
        $project.find('.preview').css('background-position', croppingOptions[index]);
        updateInfo();
    });


    // Close the window and populate input field on parent window.
    $('.fluxus-customize-note .btn-save').click(function (e) {
        e && e.preventDefault();

        var imageSizes = [],
            croppingPoints = {};

        $('.grid-project').each(function () {
            var $el = $(this),
                id = $el.data('id');

            imageSizes.push({
                id: id,
                size: $el.data('size')
            });

            croppingPoints[id] = $el.data('cropping');
        });

        window.opener.jQuery('[name="fluxus_portfolio_grid_image_sizes"]').val(JSON.stringify(imageSizes));
        window.opener.jQuery('[name="fluxus_portfolio_grid_image_cropping"]').val(JSON.stringify(croppingPoints));
        window.close();
    });


    $('.fluxus-customize-note .btn-cancel').click(function (e) {
        e && e.preventDefault();

        window.close();
    });

});

}(jQuery));